:code:`stark`
-------------------

Spectral exTraction And Reduction Kit, or :code:`stark`, is written with the aim to provide a general purpose tool for optimal extraction of spectrum from the raw (or, reduced) data with special attention towards JWST data.
The concept of the code was originally developed by Alexis Brandeker and initial versions are implemented by Marcus Karlsson and Erwan Taillanter.
Later, the code was adapted to process UVES data by Gayathri Viswanath and Maria Cavallius.
The current version of the original code is developed with keeping in mind analysis of JWST (NIRCam) data.

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   user/intro
   user/install

.. toctree::
   :maxdepth: 2
   :caption: Tutorials

   tutorials/tutorial1



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
